.. include:: ../README.rst

.. .. include:: quickstart.rst

.. .. include:: contents.rst

.. toctree::
   :maxdepth: 2
   :caption: Installation & Development

   installing
   developer

.. toctree::
   :maxdepth: 2
   :caption: Configuration

   configuring

.. toctree::
   :maxdepth: 2
   :caption: LedFx API

   api

.. toctree::
   :maxdepth: 2
   :caption: Help

   trouble

License
-------

LedFx is licensed under the MIT license.